.. image:: https://img.shields.io/pypi/v/jaraco.office.svg
   :target: https://pypi.org/project/jaraco.office

.. image:: https://img.shields.io/pypi/pyversions/jaraco.office.svg

.. image:: https://img.shields.io/travis/jaraco/jaraco.office/master.svg
   :target: https://travis-ci.org/jaraco/jaraco.office

.. .. image:: https://img.shields.io/appveyor/ci/jaraco/skeleton/master.svg
..    :target: https://ci.appveyor.com/project/jaraco/skeleton/branch/master

.. image:: https://readthedocs.org/projects/jaracooffice/badge/?version=latest
   :target: http://jaracooffice.readthedocs.io/en/latest/?badge=latest

``jaraco.office`` provides facilities for working with Microsoft Offic
applications (Word, Excel, etc) using the Win32 APIs. For cross-platform
libraries that work directly with Office 2007 OpenOffice formats, see
`ParadocX <https://github.com/yougov/paradocx>`_ and related packages.
